@@ -1,6 +1,7 @@
+import json
 import logging
 from pathlib import Path
-from typing import IO, Any, Dict, Optional, Union
+from typing import IO, Any, Dict, List, Optional, Union
 
 import yaml
 
@@ -30,14 +31,14 @@ def ensure_dir(abs_filepath: Path):
     path_obj.mkdir(parents=True, exist_ok=True)
 
 
-def write_yaml(abs_filepath: Path, yaml_dict: Dict[str, Any]):
+def write_yaml(abs_filepath: Path, yaml_data: Any):
     """
     Writes yaml dict to path
     """
     logger.debug(f'Write yaml {abs_filepath}')
     ensure_dir(abs_filepath)
     with open(abs_filepath, 'w') as f:
-        dump_yaml(yaml_dict, f)
+        dump_yaml(yaml_data, f)
 
 
 def read_yaml(path: Path) -> Dict[str, Any]:
@@ -54,6 +55,39 @@ def read_yaml(path: Path) -> Dict[str, Any]:
         raise InvalidYamlFile(path=path, error=e)
 
 
+def append_json_line(abs_filepath: Path, json_dict: Dict[str, Any]) -> None:
+    """
+    Writes json dict to path as single line. Useful to create JSON lines file. https://jsonlines.org/
+    """
+    logger.debug(f'Write json {abs_filepath}')
+    ensure_dir(abs_filepath)
+    with open(abs_filepath, 'a') as f:
+        data = json.dumps(json_dict)
+        f.write(data + '\n')
+
+
+def read_json_lines(path: Path) -> List[Dict[str, Any]]:
+    """
+    Reads json lines from path. https://jsonlines.org/
+    """
+    logger.debug(f'Read json {path}')
+    try:
+        json_lines = []
+        with open(path, 'r') as f:
+            for line in f.readlines():
+                json_lines.append(json.loads(line))
+        return json_lines
+    except FileNotFoundError:
+        raise FileMissingError(path=path)
+
+
+def truncate_file(path: Path) -> None:
+    """
+    Opening file in write mode will remove files content.
+    """
+    open(path, 'w').close()
+
+
 def delete_file(abs_filepath: Path):
     """Delete file at given path."""
     # TODO: Consider warning - wanted to delete model but not found
